# Analyse the risk of a business using Risky Business

## Functions :
1. Sharpe Ratio
2. Returns & Volatility
3. Risk by Return Ratio
4. Compounded Percentage
5. Annual Drawdown
6. Skewness & Kurtosis
7. Value Added Risk (VaR - Historic, Gaussian, Cornish-Fisher)
8. CVaR - Historic
9. VaR Comparison Plot

**Important** : Please read the [DOCUMENTATION](https://github.com/rajathkotyal/RiskyBusiness/blob/master/DOCUMENTATION.md) file before implementing any of the functions.

## Installation  

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install riskybusiness

```bash
pip install riskybusiness
```

## Usage

```python
import riskybusiness as rb
rb.FunctionName(dataset = Your_Dataset)
```
> Make sure the dataset is loaded using pandas with the necessary columns.

A sample program using all the functions is displayed in risky.ipynb
 - Open using Jupyter NB or Google Colab
 - This file contains the output samples of all the functions present in the library.

[github link](https://github.com/rajathkotyal/RiskyBusiness)

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

## License
[MIT](https://choosealicense.com/licenses/mit/)
